@@ -10,6 +10,8 @@ has 'tag' => (isa => "Maybe[Str]", is => "ro", predicate => '_has_tag',);
 has 'elem' => (isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro");
 has 'tag_elem' => (isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro");
 
+our $VERSION = '0.11.1';
+
 sub is_tag_of_name
 {
     my ($self, $name) = @_;
@@ -47,7 +49,11 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.11.0
+version 0.11.1
+
+=head1 VERSION
+
+0.11.0
 
 =head1 SLOTS
 
